@@ -27,7 +27,7 @@
 
 #include <string.h>
 
-#include "libedataserver/e-data-server-module.h"
+#include "libebackend/e-data-server-module.h"
 #include "libedata-book/e-book-backend-factory.h"
 #include "e-book-backend-file.h"
 
