@@ -170,7 +170,7 @@ typedef enum {
 	E_CONTACT_IM_YAHOO,   	 /* Multi-valued */
 	E_CONTACT_IM_MSN,     	 /* Multi-valued */
 	E_CONTACT_IM_ICQ,     	 /* Multi-valued */
-       
+
 	E_CONTACT_WANTS_HTML,    /* boolean field */
 
 	/* fields used for describing contact lists.  a contact list
@@ -186,8 +186,6 @@ typedef enum {
 	/* Security Fields */
 	E_CONTACT_X509_CERT,     /* structured field (EContactCert) */
 
-	/*New Fields Added to the Enum and Padding for future*/
-	
 	E_CONTACT_IM_GADUGADU_HOME_1,  /* Synthetic string field */
 	E_CONTACT_IM_GADUGADU_HOME_2,  /* Synthetic string field */
 	E_CONTACT_IM_GADUGADU_HOME_3,  /* Synthetic string field */
@@ -196,8 +194,10 @@ typedef enum {
 	E_CONTACT_IM_GADUGADU_WORK_3,  /* Synthetic string field */
 
 	E_CONTACT_IM_GADUGADU,   /* Multi-valued */
-	
-	E_CONTACT_GEO,	/* structured field (EContactGeo) */	
+
+	E_CONTACT_GEO,	/* structured field (EContactGeo) */
+
+	E_CONTACT_TEL, /* list of strings */
 
 	E_CONTACT_FIELD_LAST,
 	E_CONTACT_FIELD_FIRST        = E_CONTACT_UID,
