@@ -6,8 +6,8 @@
  *
  * Copyright (C) 2004 Ximian Inc.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU Lesser General Public
+ * This program is free software; you can redistribute it and/or 
+ * modify it under the terms of version 2 of the GNU Lesser General Public 
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -36,14 +36,21 @@
 #include <sys/poll.h>
 #endif
 
-#include <libedataserver/e-msgport.h>
-
 #include "camel-exception.h"
+#include "camel-msgport.h"
 #include "camel-net-utils.h"
 #include "camel-operation.h"
 
 #define d(x)
 
+/* These are GNU extensions */
+#ifndef NI_MAXHOST
+#define NI_MAXHOST	1025
+#endif
+#ifndef NI_MAXSERV
+#define NI_MAXSERV	32
+#endif
+
 #ifdef G_OS_WIN32
 
 typedef short in_port_t;
@@ -204,7 +211,7 @@ camel_gethostbyname_r (const char *name, struct hostent *host,
 	struct addrinfo hints, *res;
 	int retval, len;
 	char *addr;
-
+	
 	memset (&hints, 0, sizeof (struct addrinfo));
 #ifdef HAVE_AI_ADDRCONFIG
 	hints.ai_flags = AI_CANONNAME | AI_ADDRCONFIG;
@@ -214,49 +221,49 @@ camel_gethostbyname_r (const char *name, struct hostent *host,
 	hints.ai_family = PF_UNSPEC;
 	hints.ai_socktype = SOCK_STREAM;
 	hints.ai_protocol = IPPROTO_TCP;
-
+	
 	if ((retval = getaddrinfo (name, NULL, &hints, &res)) != 0) {
 		*herr = ai_to_herr (retval);
 		return -1;
 	}
-
+	
 	len = ALIGN (strlen (res->ai_canonname) + 1);
 	if (buflen < IPv6_BUFLEN_MIN + len + res->ai_addrlen + sizeof (char *))
 		return ERANGE;
-
+	
 	/* h_name */
 	strcpy (buf, res->ai_canonname);
 	host->h_name = buf;
 	buf += len;
-
+	
 	/* h_aliases */
 	((char **) buf)[0] = NULL;
 	host->h_aliases = (char **) buf;
 	buf += sizeof (char *);
-
+	
 	/* h_addrtype and h_length */
 	host->h_length = res->ai_addrlen;
 	if (res->ai_family == PF_INET6) {
 		host->h_addrtype = AF_INET6;
-
+		
 		addr = (char *) &((struct sockaddr_in6 *) res->ai_addr)->sin6_addr;
 	} else {
 		host->h_addrtype = AF_INET;
-
+		
 		addr = (char *) &((struct sockaddr_in *) res->ai_addr)->sin_addr;
 	}
-
+	
 	memcpy (buf, addr, host->h_length);
 	addr = buf;
 	buf += ALIGN (host->h_length);
-
+	
 	/* h_addr_list */
 	((char **) buf)[0] = addr;
 	((char **) buf)[1] = NULL;
 	host->h_addr_list = (char **) buf;
-
+	
 	freeaddrinfo (res);
-
+	
 	return 0;
 #else /* No support for IPv6 addresses */
 #ifdef HAVE_GETHOSTBYNAME_R
@@ -268,7 +275,7 @@ camel_gethostbyname_r (const char *name, struct hostent *host,
 #else
 	struct hostent *hp;
 	int retval;
-
+	
 	retval = gethostbyname_r (name, host, buf, buflen, &hp, herr);
 	if (hp != NULL) {
 		*herr = 0;
@@ -282,26 +289,26 @@ camel_gethostbyname_r (const char *name, struct hostent *host,
 		 */
 		retval = -1;
 	}
-
+	
 	return retval;
 #endif
 #else /* No support for gethostbyname_r */
 	struct hostent *h;
-
+	
 	G_LOCK (gethost_mutex);
-
+	
 	h = gethostbyname (name);
-
+	
 	if (!h) {
 		*herr = h_errno;
 		G_UNLOCK (gethost_mutex);
 		return -1;
 	}
-
+	
 	GETHOST_PROCESS (h, host, buf, buflen, herr);
-
+	
 	G_UNLOCK (gethost_mutex);
-
+	
 	return 0;
 #endif /* HAVE_GETHOSTBYNAME_R */
 #endif /* ENABLE_IPv6 */
@@ -313,38 +320,38 @@ camel_gethostbyaddr_r (const char *addr, int addrlen, int type, struct hostent *
 {
 #ifdef ENABLE_IPv6
 	int retval, len;
-
+	
 	if ((retval = getnameinfo (addr, addrlen, buf, buflen, NULL, 0, NI_NAMEREQD)) != 0) {
 		*herr = ai_to_herr (retval);
 		return -1;
 	}
-
+	
 	len = ALIGN (strlen (buf) + 1);
 	if (buflen < IPv6_BUFLEN_MIN + len + addrlen + sizeof (char *))
 		return ERANGE;
-
+	
 	/* h_name */
 	host->h_name = buf;
 	buf += len;
-
+	
 	/* h_aliases */
 	((char **) buf)[0] = NULL;
 	host->h_aliases = (char **) buf;
 	buf += sizeof (char *);
-
+	
 	/* h_addrtype and h_length */
 	host->h_length = addrlen;
 	host->h_addrtype = type;
-
+	
 	memcpy (buf, addr, host->h_length);
 	addr = buf;
 	buf += ALIGN (host->h_length);
-
+	
 	/* h_addr_list */
 	((char **) buf)[0] = addr;
 	((char **) buf)[1] = NULL;
 	host->h_addr_list = (char **) buf;
-
+	
 	return 0;
 #else /* No support for IPv6 addresses */
 #ifdef HAVE_GETHOSTBYADDR_R
@@ -356,7 +363,7 @@ camel_gethostbyaddr_r (const char *addr, int addrlen, int type, struct hostent *
 #else
 	struct hostent *hp;
 	int retval;
-
+	
 	retval = gethostbyaddr_r (addr, addrlen, type, host, buf, buflen, &hp, herr);
 	if (hp != NULL) {
 		*herr = 0;
@@ -371,26 +378,26 @@ camel_gethostbyaddr_r (const char *addr, int addrlen, int type, struct hostent *
 		 */
 		retval = -1;
 	}
-
+	
 	return retval;
 #endif
 #else /* No support for gethostbyaddr_r */
 	struct hostent *h;
-
+	
 	G_LOCK (gethost_mutex);
-
+	
 	h = gethostbyaddr (addr, addrlen, type);
-
+	
 	if (!h) {
 		*herr = h_errno;
 		G_UNLOCK (gethost_mutex);
 		return -1;
 	}
-
+	
 	GETHOST_PROCESS (h, host, buf, buflen, herr);
-
+	
 	G_UNLOCK (gethost_mutex);
-
+	
 	return 0;
 #endif /* HAVE_GETHOSTBYADDR_R */
 #endif /* ENABLE_IPv6 */
@@ -399,7 +406,7 @@ camel_gethostbyaddr_r (const char *addr, int addrlen, int type, struct hostent *
 
 /* ********************************************************************** */
 struct _addrinfo_msg {
-	EMsg msg;
+	CamelMsg msg;
 	unsigned int cancelled:1;
 
 	/* for host lookup */
@@ -441,7 +448,7 @@ cs_freeinfo(struct _addrinfo_msg *msg)
 static int
 cs_waitinfo(void *(worker)(void *), struct _addrinfo_msg *msg, const char *error, CamelException *ex)
 {
-	EMsgPort *reply_port;
+	CamelMsgPort *reply_port;
 	pthread_t id;
 	int err, cancel_fd, cancel = 0, fd;
 
@@ -450,9 +457,9 @@ cs_waitinfo(void *(worker)(void *), struct _addrinfo_msg *msg, const char *error
 		worker(msg);
 		return 0;
 	}
-
-	reply_port = msg->msg.reply_port = e_msgport_new();
-	fd = e_msgport_fd(msg->msg.reply_port);
+	
+	reply_port = msg->msg.reply_port = camel_msgport_new();
+	fd = camel_msgport_fd(msg->msg.reply_port);
 	if ((err = pthread_create(&id, NULL, worker, msg)) == 0) {
 		int status;
 #ifndef G_OS_WIN32
@@ -496,7 +503,7 @@ cs_waitinfo(void *(worker)(void *), struct _addrinfo_msg *msg, const char *error
 						     );
 			else
 				camel_exception_setv(ex, CAMEL_EXCEPTION_USER_CANCEL, _("Canceled"));
-
+			
 			/* We cancel so if the thread impl is decent it causes immediate exit.
 			   We detach so we dont need to wait for it to exit if it isn't.
 			   We check the reply port incase we had a reply in the mean time, which we free later */
@@ -506,7 +513,7 @@ cs_waitinfo(void *(worker)(void *), struct _addrinfo_msg *msg, const char *error
 			pthread_cancel(id);
 			cancel = 1;
 		} else {
-			struct _addrinfo_msg *reply = (struct _addrinfo_msg *)e_msgport_get(reply_port);
+			struct _addrinfo_msg *reply = (struct _addrinfo_msg *)camel_msgport_try_pop(reply_port);
 
 			g_assert(reply == msg);
 			d(printf("waiting for child to exit\n"));
@@ -516,7 +523,7 @@ cs_waitinfo(void *(worker)(void *), struct _addrinfo_msg *msg, const char *error
 	} else {
 		camel_exception_setv(ex, CAMEL_EXCEPTION_SYSTEM, "%s: %s: %s", error, _("cannot create thread"), g_strerror(err));
 	}
-	e_msgport_destroy(reply_port);
+	camel_msgport_destroy(reply_port);
 
 	return cancel;
 }
@@ -540,7 +547,7 @@ cs_getaddrinfo(void *data)
                 msg->hostbuflen *= 2;
                 msg->hostbufmem = g_realloc(msg->hostbufmem, msg->hostbuflen);
 	}
-
+	
 	/* If we got cancelled, dont reply, just free it */
 	if (msg->cancelled)
 		goto cancel;
@@ -622,7 +629,7 @@ cs_getaddrinfo(void *data)
 		}
 	}
 reply:
-	e_msgport_reply((EMsg *)msg);
+	camel_msgport_reply((CamelMsg *)msg);
 	return NULL;
 cancel:
 	cs_freeinfo(msg);
@@ -635,13 +642,13 @@ cs_getaddrinfo(void *data)
 	struct _addrinfo_msg *info = data;
 
 	info->result = getaddrinfo(info->name, info->service, info->hints, info->res);
-
+	
 	if (info->cancelled) {
 		cs_freeinfo(info);
 	} else {
-		e_msgport_reply((EMsg *)info);
+		camel_msgport_reply((CamelMsg *)info);
 	}
-
+	
 	return NULL;
 }
 #endif /* NEED_ADDRINFO */
@@ -655,7 +662,7 @@ camel_getaddrinfo(const char *name, const char *service, const struct addrinfo *
 	struct addrinfo myhints;
 #endif
 	g_return_val_if_fail(name != NULL, NULL);
-
+	
 	if (camel_operation_cancel_check(NULL)) {
 		camel_exception_set(ex, CAMEL_EXCEPTION_USER_CANCEL, _("Canceled"));
 		return NULL;
@@ -669,7 +676,7 @@ camel_getaddrinfo(const char *name, const char *service, const struct addrinfo *
 		memset(&myhints, 0, sizeof(myhints));
 	else
 		memcpy (&myhints, hints, sizeof (myhints));
-
+	
 	myhints.ai_family = AF_INET;
 	hints = &myhints;
 #endif
@@ -738,7 +745,7 @@ cs_getnameinfo(void *data)
                 msg->hostbuflen *= 2;
                 msg->hostbufmem = g_realloc(msg->hostbufmem, msg->hostbuflen);
 	}
-
+	
 	if (msg->cancelled)
 		goto cancel;
 
@@ -748,7 +755,7 @@ cs_getnameinfo(void *data)
 			msg->host = g_strdup(h.h_name);
 		} else {
 			unsigned char *in = (unsigned char *)&sin->sin_addr;
-
+			
 			/* sin_addr is always network order which is big-endian */
 			msg->host = g_strdup_printf("%u.%u.%u.%u", in[0], in[1], in[2], in[3]);
 		}
@@ -758,7 +765,7 @@ cs_getnameinfo(void *data)
 	if (msg->serv)
 		sprintf(msg->serv, "%d", sin->sin_port);
 
-	e_msgport_reply((EMsg *)msg);
+	camel_msgport_reply((CamelMsg *)msg);
 	return NULL;
 cancel:
 	cs_freeinfo(msg);
@@ -772,11 +779,11 @@ cs_getnameinfo(void *data)
 
 	/* there doens't appear to be a return code which says host or serv buffers are too short, lengthen them */
 	msg->result = getnameinfo(msg->addr, msg->addrlen, msg->host, msg->hostlen, msg->serv, msg->servlen, msg->flags);
-
+	
 	if (msg->cancelled)
 		cs_freeinfo(msg);
 	else
-		e_msgport_reply((EMsg *)msg);
+		camel_msgport_reply((CamelMsg *)msg);
 
 	return NULL;
 }
