@@ -492,7 +492,7 @@ camel_service_get_url (CamelService *service)
 static char *
 get_name (CamelService *service, gboolean brief)
 {
-	w(g_warning ("CamelService::get_name not implemented for `%s'",
+	w(g_warning ("CamelService::get_name not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (service))));
 	return g_strdup ("???");
 }		
@@ -637,12 +637,14 @@ GList *
 camel_service_query_auth_types (CamelService *service, CamelException *ex)
 {
 	GList *ret;
-	
+
+	g_return_val_if_fail (service != NULL, NULL);
+
 	/* note that we get the connect lock here, which means the callee
 	   must not call the connect functions itself */
 	CAMEL_SERVICE_REC_LOCK (service, connect_lock);
 	ret = CSERV_CLASS (service)->query_auth_types (service, ex);
 	CAMEL_SERVICE_REC_UNLOCK (service, connect_lock);
-	
+
 	return ret;
 }
