@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -197,7 +197,7 @@ text_index_add_name_to_word(CamelIndex *idx, const char *word, camel_key_t namei
 			rb->words++;
 			camel_block_file_touch_block(p->blocks, p->blocks->root_block);
 		} else {
-			data = camel_key_table_lookup(p->word_index, wordid, NULL, 0);
+			data = camel_key_table_lookup(p->word_index, wordid, NULL, NULL);
 			if (data == 0) {
 				g_warning ("Could not find key entry for word '%s': %s\n",
 					   word, strerror (errno));
@@ -263,7 +263,9 @@ text_index_sync(CamelIndex *idx)
 
 	d(printf("sync: blocks = %p\n", p->blocks));
 
-	if (p->blocks == NULL)
+	if (p->blocks == NULL || p->links == NULL
+	    || p->word_index == NULL || p->word_hash == NULL
+	    || p->name_index == NULL || p->name_hash == NULL)
 		return 0;
 
 	rb = (struct _CamelTextIndexRoot *)p->blocks->root;
@@ -843,15 +845,17 @@ camel_text_index_new(const char *path, int flags)
 	sprintf(link, "%s.data", idx->parent.path);
 	p->links = camel_key_file_new(link, flags, CAMEL_TEXT_INDEX_KEY_VERSION);
 
-	if (p->blocks == NULL || p->links == NULL) {
-		camel_object_unref((CamelObject *)idx);
-		return NULL;
-	}
+	if (p->blocks == NULL || p->links == NULL)
+		goto fail;
 
 	rb = (struct _CamelTextIndexRoot *)p->blocks->root;
 
 	if (rb->word_index_root == 0) {
 		bl = camel_block_file_new_block(p->blocks);
+
+		if (bl == NULL)
+			goto fail;
+
 		rb->word_index_root = bl->id;
 		camel_block_file_unref_block(p->blocks, bl);
 		camel_block_file_touch_block(p->blocks, p->blocks->root_block);
@@ -859,6 +863,10 @@ camel_text_index_new(const char *path, int flags)
 
 	if (rb->word_hash_root == 0) {
 		bl = camel_block_file_new_block(p->blocks);
+
+		if (bl == NULL)
+			goto fail;
+
 		rb->word_hash_root = bl->id;
 		camel_block_file_unref_block(p->blocks, bl);
 		camel_block_file_touch_block(p->blocks, p->blocks->root_block);
@@ -866,6 +874,10 @@ camel_text_index_new(const char *path, int flags)
 
 	if (rb->name_index_root == 0) {
 		bl = camel_block_file_new_block(p->blocks);
+
+		if (bl == NULL)
+			goto fail;
+
 		rb->name_index_root = bl->id;
 		camel_block_file_unref_block(p->blocks, bl);
 		camel_block_file_touch_block(p->blocks, p->blocks->root_block);
@@ -873,6 +885,10 @@ camel_text_index_new(const char *path, int flags)
 
 	if (rb->name_hash_root == 0) {
 		bl = camel_block_file_new_block(p->blocks);
+
+		if (bl == NULL)
+			goto fail;
+
 		rb->name_hash_root = bl->id;
 		camel_block_file_unref_block(p->blocks, bl);
 		camel_block_file_touch_block(p->blocks, p->blocks->root_block);
@@ -890,6 +906,10 @@ camel_text_index_new(const char *path, int flags)
 	}
 
 	return idx;
+
+fail:
+	camel_object_unref((CamelObject *)idx);
+	return NULL;
 }
 
 /* returns 0 if the index exists, is valid, and synced, -1 otherwise */
@@ -1450,8 +1470,8 @@ text_index_name_add_buffer(CamelIndexName *idn, const char *buffer, size_t len)
 	CamelTextIndexNamePrivate *p = CIN_PRIVATE(idn);
 	const unsigned char *ptr, *ptrend;
 	guint32 c;
-	unsigned char utf8[8];
-	size_t utf8len;
+	char utf8[8];
+	int utf8len;
 
 	if (buffer == NULL) {
 		if (p->buffer->len) {
@@ -1461,8 +1481,8 @@ text_index_name_add_buffer(CamelIndexName *idn, const char *buffer, size_t len)
 		return 0;
 	}
 
-	ptr = buffer;
-	ptrend = buffer+len;
+	ptr = (const unsigned char *) buffer;
+	ptrend = (const unsigned char *) buffer+len;
 	while ((c = camel_utf8_next(&ptr, ptrend))) {
 		if (g_unichar_isalnum(c)) {
 			c = g_unichar_tolower(c);
