@@ -1,15 +1,15 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* camel-url.c : utility functions to parse URLs */
 
-/*
+/* 
  * Authors:
  *  Dan Winship <danw@ximian.com>
  *  Jeffrey Stedfast <fejj@ximian.com>
  *
  * Copyright 1999-2001 Ximian, Inc. (www.ximian.com)
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU Lesser General Public
+ * This program is free software; you can redistribute it and/or 
+ * modify it under the terms of version 2 of the GNU Lesser General Public 
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -302,14 +302,15 @@ camel_url_new (const char *url_string, CamelException *ex)
 {
 	CamelURL *url;
 
-	g_return_val_if_fail (url_string != NULL, NULL);
+	if (!url_string || !*url_string)
+		return NULL;
 
 	url = camel_url_new_with_base (NULL, url_string);
 
 	if (!url->protocol) {
 		camel_url_free (url);
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SERVICE_URL_INVALID,
-				      _("Could not parse URL `%s'"),
+				      _("Could not parse URL '%s'"),
 				      url_string);
 		return NULL;
 	}
@@ -351,7 +352,7 @@ camel_url_to_string (CamelURL *url, guint32 flags)
 		g_string_append (str, "//");
 		if (url->user) {
 			append_url_encoded (str, url->user, ":;@/");
-			if (url->authmech && *url->authmech) {
+			if (url->authmech && *url->authmech && !(flags & CAMEL_URL_HIDE_AUTH)) {
 				g_string_append (str, ";auth=");
 				append_url_encoded (str, url->authmech, ":@/");
 			}
@@ -367,7 +368,7 @@ camel_url_to_string (CamelURL *url, guint32 flags)
 		if (!url->path && (url->params || url->query || url->fragment))
 			g_string_append_c (str, '/');
 	}
-
+	
 	if (url->path)
 		append_url_encoded (str, url->path, ";?");
 	if (url->params && !(flags & CAMEL_URL_HIDE_PARAMS))
@@ -380,10 +381,10 @@ camel_url_to_string (CamelURL *url, guint32 flags)
 		g_string_append_c (str, '#');
 		append_url_encoded (str, url->fragment, NULL);
 	}
-
+	
 	return_result = str->str;
 	g_string_free (str, FALSE);
-
+	
 	return return_result;
 }
 
@@ -425,7 +426,7 @@ camel_url_free (CamelURL *url)
 		g_datalist_clear (&url->params);
 		g_free (url->query);
 		g_free (url->fragment);
-
+		
 		g_free (url);
 	}
 }
@@ -679,7 +680,7 @@ camel_url_hash (const void *v)
 	ADD_HASH (u->path);
 	ADD_HASH (u->query);
 	hash ^= u->port;
-
+	
 	return hash;
 }
 
@@ -692,7 +693,7 @@ check_equal (char *s1, char *s2)
 		else
 			return FALSE;
 	}
-
+	
 	if (s2 == NULL)
 		return FALSE;
 
