@@ -80,6 +80,8 @@ ExchangeAccount       *exchange_account_new                  (EAccountList *acco
 E2kContext            *exchange_account_get_context          (ExchangeAccount  *acct);
 E2kGlobalCatalog      *exchange_account_get_global_catalog   (ExchangeAccount  *acct);
 
+EAccount 	      *exchange_account_fetch 		     (ExchangeAccount *acct);
+
 const char            *exchange_account_get_standard_uri     (ExchangeAccount  *acct,
 							      const char       *item);
 
@@ -110,15 +112,13 @@ void                   exchange_account_rescan_tree          (ExchangeAccount  *
 
 char 		      *exchange_account_get_password 	     (ExchangeAccount  *acct);
 
-#ifdef HAVE_KRB5
 ExchangeAccountResult exchange_account_set_password 	     (ExchangeAccount  *acct,
 							      char             *old_password,
 							      char             *new_password);
-#endif
 
 void 		       exchange_account_forget_password       (ExchangeAccount  *acct);
 
-void		       exchange_account_set_save_password    (ExchangeAccount *account, 
+void		       exchange_account_set_save_password    (ExchangeAccount *account,
 							      gboolean save_password);
 
 gboolean	       exchange_account_is_save_password     (ExchangeAccount *account);
@@ -179,6 +179,8 @@ gboolean exchange_account_is_favorite_folder              (ExchangeAccount *acco
 
 char * exchange_account_get_username 			  (ExchangeAccount *account);
 
+char * exchange_account_get_windows_domain 		  (ExchangeAccount *account);
+
 char * exchange_account_get_email_id 			  (ExchangeAccount *account);
 
 int exchange_account_get_quota_limit			  (ExchangeAccount *account);
@@ -195,6 +197,8 @@ void 			exchange_account_folder_size_rename (ExchangeAccount *account,
 						     	     const char *old_name,
 						     	     const char *new_name);
 GtkListStore 	       *exchange_account_folder_size_get_model (ExchangeAccount *account);
+void 		  	exchange_account_scan_foreign_hierarchy (ExchangeAccount *account,
+							      const char *user_email);
 
 
 #ifdef __cplusplus
